///////////////////////////////////////////////////////////////////////////
//
// Copyright (c) 2004 Intel Corporation 
// All rights reserved. 
//
// Redistribution and use in source and binary forms, with or without 
// modification, are permitted provided that the following conditions are met: 
//
// * Redistributions of source code must retain the above copyright notice, 
// this list of conditions and the following disclaimer. 
// * Redistributions in binary form must reproduce the above copyright notice, 
// this list of conditions and the following disclaimer in the documentation 
// and/or other materials provided with the distribution. 
// * Neither name of Intel Corporation nor the names of its contributors 
// may be used to endorse or promote products derived from this software 
// without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR 
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL INTEL OR 
// CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
// PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR 
// PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY 
// OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
// NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//
///////////////////////////////////////////////////////////////////////////

//
// FIR.cpp: Demonstrate a simple filter using FIR
//

#include "stdafx.h"
#include "ipp.h"
#include "tools.h"

void myMakeSrc_32f(Ipp32f** pSig, int len)
{
	*pSig = ippsMalloc_32f(len);

	ippsVectorJaehne_32f( *pSig, len, 1 );
}

void myMakeDst_32f(Ipp32f** pSig, int len)
{
	*pSig = ippsMalloc_32f(len);

	ippsZero_32f( *pSig, len );
}

void myFilterA_32f(Ipp32f* pSrc, Ipp32f*pDst, int len)
{
	Ipp32f taps[] = { 0.25f, 0.5f, 0.25f };
	// Another simple filter:
	//	Ipp32f taps[] = { -0.5f, 0.0f, 0.5f };
	Ipp32f dlyl[] = { 0.0f, 0.0f, 0.0f};

	IppsFIRState_32f *pFIRState;
	ippsFIRInitAlloc_32f( &pFIRState, taps, 3, dlyl );
	/// filter the signal by the FIR filter
	ippsFIR_32f(pSrc, pDst, len, pFIRState );
	ippsFIRFree_32f(pFIRState);

}

int main(int argc, char* argv[])
{
	int i;
	Ipp32f* pSrc, *pDst;

	// Set drawing settings to distinguish the two signals
	DrawingSettings settings = 
	{
		1,2,
		PS_SOLID, PS_SOLID,
		0x00808080, 0x00000000,
		1,1,
		0x00cfcfcf, 0x007f7f7f
	};

	for (i=32; i<=2048; i*=2)
	{
		myMakeSrc_32f(&pSrc,i);
		myMakeDst_32f(&pDst,i);
		myFilterA_32f(pSrc, pDst, i);
		spView2_32f( pSrc, i, pDst, i, " Original & filtered", 1, settings );
		ippsFree(pDst);
		ippsFree(pSrc);
	}

	return 0;
}

